**1.0.30 - 06/11/2020**

 - Add path for mask/contact interaction covariate.

**1.0.29 - 06/08/2020**

 - Add path for contact covariate.

**1.0.28 - 05/31/2020**

 - Add path for pneumonia covariate.

**1.0.27 - 05/29/2020**

 - Hotfix for bug in decorator method

**1.0.26 - 05/29/2020**

 - Create common click option decorators for CLI methods

**1.0.25 - 05/28/2020**

 - Hotfix in import paths to preserve backwards compatibility.

**1.0.24 - 05/28/2020**

 - Refactor cli_tools as a subpackage
 - Add mobility gpr path

**1.0.23 - 05/25/2020**

 - Redirect deaths outputs.

**1.0.22 - 05/24/2020**

 - New outputs root for deaths

**1.0.21 - 05/21/2020**

 - Mask use paths.
 - shared repo path.

**1.0.20 - 05/21/2020**

 - Fix yaml warning.

**1.0.19 - 05/21/2020**

 - Update singularity paths for executing R scripts.

**1.0.18 - 05/20/2020**

 - Add more seiir paths.

**1.0.17 - 05/19/2020**

 - Fix default R singularity image path

**1.0.16 - 05/18/2020**

 - Bugfix in metadata file comparison.

**1.0.15 - 05/16/2020**

 - Add shared paths used in testing covariate.
 - Change lots of stuff to path objects.
 - Add update from path method to run metadata.
 - Add paths for seiir inputs and outputs.

**1.0.14 - 05/12/2020**

 - Add static data root.

**1.0.13 - 05/12/2020**

 - Add unversioned inputs root.

**1.0.12 - 05/12/2020**

 - Refactor of get_last_stage_directory to be a bit smarter.
 - Add NOAA data.

**1.0.11 - 05/01/2020**

 - Add a path for raw covariates.

**1.0.10 - 04/30/2020**

 - Add new paths for covariate gathering
 - Update cli tools to support QC functions.

**1.0.9 - 04/28/2020**

 - Adjust update with previous metadata.

**1.0.8 - 04/28/2020**

 - Error on bad production dir name.
 - Add output root for deaths model.
 - Extract some convenience functions to reduce cli boilerplate.

**1.0.7 - 04/26/2020**

 - Additional logging utilities
 - Better mkdir support
 - Expanded marking functions.

**1.0.6 - 04/22/2020**

 - Bugfix in symlink handling.
 - Add general method to create dirs with reasonable permissions.

**1.0.5 - 04/18/2020**

 - Add NY times output directory name.

**1.0.4 - 04/18/2020**

 - Add NY times repo path.
 - Add success flag to metadata when successful.

**1.0.3 - 04/16/2020**

 - Add tool tracking to metadata.

**1.0.2 - 04/14/2020**

 - Add authors, code of conduct, contributing guide.

**1.0.1 - 04/14/2020**

 - Deployment updates.

**1.0.0 - 04/14/2020**

 - Initial release.
